==> assertive_0.3-2.tar.gz: assertive/R/exports-files.R <==
# From assertive.files is-connection.R, assert-is-connection.R

#' Is the input a connection?
#' 
#' See \code{\link[assertive.files]{is_connection}}.
#' @name is_connection
#' @aliases is_bzfile_connection is_fifo_connection is_file_connection is_gzfile_connection is_incomplete_connection is_open_connection is_pipe_connection is_readable_connection is_socket_connection is_stderr is_stdin is_stdout is_terminal_connection is_text_connection is_unz_connection is_url_connection is_writable_connection is_xzfile_connection assert_is_connection assert_is_bzfile_connection assert_is_fifo_connection assert_is_file_connection assert_is_gzfile_connection assert_is_incomplete_connection assert_is_open_connection assert_is_pipe_connection assert_is_readable_connection assert_is_socket_connection assert_is_stderr assert_is_stdin assert_is_stdout assert_is_terminal_connection assert_is_text_connection assert_is_unz_connection assert_is_url_connection assert_is_writable_connection assert_is_xzfile_connection
#' @export is_connection
#' @export is_bzfile_connection
#' @export is_fifo_connection
#' @export is_file_connection
#' @export is_gzfile_connection
#' @export is_incomplete_connection
#' @export is_open_connection
#' @export is_pipe_connection
#' @export is_readable_connection
#' @export is_socket_connection
#' @export is_stderr
#' @export is_stdin
#' @export is_stdout
#' @export is_terminal_connection
#' @export is_text_connection
#' @export is_unz_connection
#' @export is_url_connection
#' @export is_writable_connection
#' @export is_xzfile_connection
#' @export assert_is_connection
#' @export assert_is_bzfile_connection
#' @export assert_is_fifo_connection
#' @export assert_is_file_connection
#' @export assert_is_gzfile_connection
#' @export assert_is_incomplete_connection
#' @export assert_is_open_connection
#' @export assert_is_pipe_connection
#' @export assert_is_readable_connection
#' @export assert_is_socket_connection
#' @export assert_is_stderr
#' @export assert_is_stdin
#' @export assert_is_stdout
#' @export assert_is_terminal_connection
#' @export assert_is_text_connection
#' @export assert_is_unz_connection
#' @export assert_is_url_connection
#' @export assert_is_writable_connection
#' @export assert_is_xzfile_connection
NULL

# From assertive.files is-file.R, assert-is-file.R

#' Is the path a directory?
#' 
#' See \code{\link[assertive.files]{is_dir}}.
#' @name is_dir
#' @aliases assert_all_are_dirs assert_any_are_dirs
#' @export is_dir
#' @export assert_all_are_dirs
#' @export assert_any_are_dirs
NULL

#' Is a file empty?
#' 
#' See \code{\link[assertive.files]{is_empty_file}}.
#' @name is_empty_file
#' @aliases is_non_empty_file is_file_size_in_range assert_all_are_empty_files assert_any_are_empty_files assert_all_are_non_empty_files assert_any_are_non_empty_files
#' @export is_empty_file
#' @export is_non_empty_file
#' @export is_file_size_in_range
#' @export assert_all_are_empty_files
#' @export assert_any_are_empty_files
#' @export assert_all_are_non_empty_files
#' @export assert_any_are_non_empty_files
NULL

#' Does the file exist?
#' 
#' See \code{\link[assertive.files]{is_existing_file}}.
#' @name is_existing_file
#' @aliases assert_all_are_existing_files assert_any_are_existing_files
#' @export is_existing_file
#' @export assert_all_are_existing_files
#' @export assert_any_are_existing_files
NULL

#' Is the file accessible?
#' 
#' See \code{\link[assertive.files]{is_executable_file}}.
#' @name is_executable_file
#' @aliases is_ex_file is_readable_file is_writable_file assert_all_are_executable_files assert_any_are_executable_files assert_all_are_ex_files assert_any_are_ex_files assert_all_are_readable_files assert_any_are_readable_files assert_all_are_writable_files assert_any_are_writable_files 
#' @export is_executable_file
#' @export is_ex_file
#' @export is_readable_file
#' @export is_writable_file
#' @export assert_all_are_executable_files
#' @export assert_any_are_executable_files
#' @export assert_all_are_readable_files
#' @export assert_any_are_readable_files
#' @export assert_all_are_writable_files
#' @export assert_any_are_writable_files
NULL

#' Is the directory a known R library?
#' 
#' See \code{\link[assertive.files]{is_library}}.
#' @name is_library
#' @aliases assert_all_are_libraries assert_any_are_libraries
#' @export is_library
#' @export assert_all_are_libraries
#' @export assert_any_are_libraries
NULL

==> assertive_0.3-6.tar.gz: assertive/R/exports-files.R <==
# From assertive.files is-connection.R, assert-is-connection.R

#' Is the input a connection?
#' 
#' See \code{\link[assertive.files]{is_connection}}.
#' @name is_connection
#' @aliases is_bzfile_connection is_fifo_connection is_file_connection is_gzfile_connection is_incomplete_connection is_open_connection is_pipe_connection is_readable_connection is_socket_connection is_stderr is_stdin is_stdout is_terminal_connection is_text_connection is_unz_connection is_url_connection is_writable_connection is_xzfile_connection assert_is_connection assert_is_bzfile_connection assert_is_fifo_connection assert_is_file_connection assert_is_gzfile_connection assert_is_incomplete_connection assert_is_open_connection assert_is_pipe_connection assert_is_readable_connection assert_is_socket_connection assert_is_stderr assert_is_stdin assert_is_stdout assert_is_terminal_connection assert_is_text_connection assert_is_unz_connection assert_is_url_connection assert_is_writable_connection assert_is_xzfile_connection
#' @export is_connection
#' @export is_bzfile_connection
#' @export is_fifo_connection
#' @export is_file_connection
#' @export is_gzfile_connection
#' @export is_incomplete_connection
#' @export is_open_connection
#' @export is_pipe_connection
#' @export is_readable_connection
#' @export is_socket_connection
#' @export is_stderr
#' @export is_stdin
#' @export is_stdout
#' @export is_terminal_connection
#' @export is_text_connection
#' @export is_unz_connection
#' @export is_url_connection
#' @export is_writable_connection
#' @export is_xzfile_connection
#' @export assert_is_connection
#' @export assert_is_bzfile_connection
#' @export assert_is_fifo_connection
#' @export assert_is_file_connection
#' @export assert_is_gzfile_connection
#' @export assert_is_incomplete_connection
#' @export assert_is_open_connection
#' @export assert_is_pipe_connection
#' @export assert_is_readable_connection
#' @export assert_is_socket_connection
#' @export assert_is_stderr
#' @export assert_is_stdin
#' @export assert_is_stdout
#' @export assert_is_terminal_connection
#' @export assert_is_text_connection
#' @export assert_is_unz_connection
#' @export assert_is_url_connection
#' @export assert_is_writable_connection
#' @export assert_is_xzfile_connection
NULL

# From assertive.files is-file.R, assert-is-file.R

#' Is the path a directory?
#' 
#' See \code{\link[assertive.files]{is_dir}}.
#' @name is_dir
#' @aliases assert_all_are_dirs assert_any_are_dirs
#' @export is_dir
#' @export assert_all_are_dirs
#' @export assert_any_are_dirs
NULL

#' Does the file exist?
#' 
#' See \code{\link[assertive.files]{is_existing_file}}.
#' @name is_existing_file
#' @aliases assert_all_are_existing_files assert_any_are_existing_files
#' @export is_existing_file
#' @export assert_all_are_existing_files
#' @export assert_any_are_existing_files
NULL

#' Is the file accessible?
#' 
#' See \code{\link[assertive.files]{is_executable_file}}.
#' @name is_executable_file
#' @aliases is_ex_file is_readable_file is_writable_file assert_all_are_executable_files assert_any_are_executable_files assert_all_are_ex_files assert_any_are_ex_files assert_all_are_readable_files assert_any_are_readable_files assert_all_are_writable_files assert_any_are_writable_files 
#' @export is_executable_file
#' @export is_ex_file
#' @export is_readable_file
#' @export is_writable_file
#' @export assert_all_are_executable_files
#' @export assert_any_are_executable_files
#' @export assert_all_are_readable_files
#' @export assert_any_are_readable_files
#' @export assert_all_are_writable_files
#' @export assert_any_are_writable_files
NULL

#' Is the directory a known R library?
#' 
#' See \code{\link[assertive.files]{is_library}}.
#' @name is_library
#' @aliases assert_all_are_libraries assert_any_are_libraries
#' @export is_library
#' @export assert_all_are_libraries
#' @export assert_any_are_libraries
NULL

# From assertive.files is-file-empty.R, assert-is-file-empty.R

#' Is a file too big or small?
#' 
#' See \code{\link[assertive.files]{is_empty_file}}.
#' @name is_empty_file
#' @aliases is_non_empty_file is_file_size_in_range assert_all_are_empty_files assert_any_are_empty_files assert_all_are_non_empty_files assert_any_are_non_empty_files assert_all_file_sizes_are_in_range assert_any_file_sizes_are_in_range
#' @export is_empty_file
#' @export is_non_empty_file
#' @export is_file_size_in_range
#' @export assert_all_are_empty_files
#' @export assert_any_are_empty_files
#' @export assert_all_are_non_empty_files
#' @export assert_any_are_non_empty_files
#' @export assert_all_file_sizes_are_in_range
#' @export assert_any_file_sizes_are_in_range
NULL
